@@ -244,8 +244,9 @@ func getInitData(ctx context.Context) *initialisation.InitData {
 		return initialisation.NewErrorInitData(fmt.Errorf("failed to load workspace: %s", errAndWarnings.GetError().Error()))
 	}
 
-	i := initialisation.NewInitData(w).Init(ctx, constants.InvokerDashboard)
-	i.Result.AddWarnings(errAndWarnings.Warnings...)
+	i := initialisation.NewInitData()
+	i.Workspace = w
+	i.Init(ctx, constants.InvokerDashboard)
 
 	if len(viper.GetStringSlice(constants.ArgExport)) > 0 {
 		i.RegisterExporters(dashboardExporters()...)
@@ -279,9 +280,12 @@ func runSingleDashboard(ctx context.Context, targetName string, inputs map[strin
 	}
 	// targetName must be a named resource
 	// parse the name to verify
-	if err := verifyNamedResource(targetName, initData.Workspace); err != nil {
+	targetResource, err := verifyNamedResource(targetName, initData.Workspace)
+	if err != nil {
 		return err
 	}
+	// update name to make sure it is fully qualified
+	targetName = targetResource.Name()
 
 	// if there is a usage warning we display it
 	initData.Result.DisplayMessages()
@@ -304,24 +308,32 @@ func runSingleDashboard(ctx context.Context, targetName string, inputs map[strin
 
 	// export the result (if needed)
 	exportArgs := viper.GetStringSlice(constants.ArgExport)
-	err = initData.ExportManager.DoExport(ctx, snap.FileNameRoot, snap, exportArgs)
+	exportMsg, err := initData.ExportManager.DoExport(ctx, snap.FileNameRoot, snap, exportArgs)
 	error_helpers.FailOnErrorWithMessage(err, "failed to export snapshot")
 
+	// print the location where the file is exported
+	if len(exportMsg) > 0 && viper.GetBool(constants.ArgProgress) {
+		fmt.Printf("\n")
+		fmt.Println(strings.Join(exportMsg, "\n"))
+		fmt.Printf("\n")
+	}
+
 	return nil
 }
 
-func verifyNamedResource(targetName string, w *workspace.Workspace) error {
+func verifyNamedResource(targetName string, w *workspace.Workspace) (modconfig.HclResource, error) {
 	parsedName, err := modconfig.ParseResourceName(targetName)
 	if err != nil {
-		return fmt.Errorf("dashboard command cannot run arbitrary SQL")
+		return nil, fmt.Errorf("dashboard command cannot run arbitrary SQL")
 	}
 	if parsedName.ItemType == "" {
-		return fmt.Errorf("dashboard command cannot run arbitrary SQL")
+		return nil, fmt.Errorf("dashboard command cannot run arbitrary SQL")
 	}
-	if _, found := w.GetResource(parsedName); !found {
-		return fmt.Errorf("'%s' not found in %s (%s)", targetName, w.Mod.Name(), w.Path)
+	if r, found := w.GetResource(parsedName); !found {
+		return nil, fmt.Errorf("'%s' not found in %s (%s)", targetName, w.Mod.Name(), w.Path)
+	} else {
+		return r, nil
 	}
-	return nil
 }
 
 func publishSnapshotIfNeeded(ctx context.Context, snapshot *dashboardtypes.SteampipeSnapshot) error {
