@@ -216,7 +216,6 @@ func runPluginInstallCmd(cmd *cobra.Command, args []string) {
 	// a leading blank line - since we always output multiple lines
 	fmt.Println()
 
-	statusSpinner := statushooks.NewStatusSpinner()
 	progressBars := uiprogress.New()
 	installWaitGroup := &sync.WaitGroup{}
 	dataChannel := make(chan *display.PluginInstallReport, len(plugins))
@@ -237,9 +236,10 @@ func runPluginInstallCmd(cmd *cobra.Command, args []string) {
 	}
 
 	progressBars.Stop()
-	statusSpinner.UpdateSpinnerMessage("Refreshing connections...")
+
+	statushooks.SetStatus(ctx, "Refreshing connections...")
 	refreshConnectionsIfNecessary(ctx, installReports, true)
-	statusSpinner.Done()
+	statushooks.Done(ctx)
 	display.PrintInstallReports(installReports, false)
 
 	// a concluding blank line - since we always output multiple lines
@@ -373,14 +373,13 @@ func runPluginUpdateCmd(cmd *cobra.Command, args []string) {
 		fmt.Println()
 		return
 	}
-	statusSpinner := statushooks.NewStatusSpinner(statushooks.WithMessage("Checking for available updates"))
 
-	timeoutCtx, cancel := context.WithTimeout(cmd.Context(), 30*time.Second)
+	timeoutCtx, cancel := context.WithTimeout(ctx, 30*time.Second)
 	defer cancel()
 
+	statushooks.SetStatus(ctx, "Checking for available updates")
 	reports := plugin.GetUpdateReport(timeoutCtx, state.InstallationID, runUpdatesFor)
-	statusSpinner.Done()
-
+	statushooks.Done(ctx)
 	if len(reports) == 0 {
 		// this happens if for some reason the update server could not be contacted,
 		// in which case we get back an empty map
@@ -408,11 +407,8 @@ func runPluginUpdateCmd(cmd *cobra.Command, args []string) {
 	for updateResult := range dataChannel {
 		updateResults = append(updateResults, updateResult)
 	}
-	// prevent fdw update message
-	nullStatusHookCtx := statushooks.DisableStatusHooks(ctx)
-	refreshConnectionsIfNecessary(nullStatusHookCtx, updateResults, false)
 	progressBars.Stop()
-	fmt.Println()
+	refreshConnectionsIfNecessary(ctx, updateResults, false)
 	display.PrintInstallReports(updateResults, true)
 
 	// a concluding blank line - since we always output multiple lines
@@ -528,7 +524,7 @@ func resolveUpdatePluginsFromArgs(args []string) ([]string, error) {
 }
 
 // start service if necessary and refresh connections
-func refreshConnectionsIfNecessary(ctx context.Context, reports display.PluginInstallReports, shouldReload bool) error {
+func refreshConnectionsIfNecessary(parentCtx context.Context, reports display.PluginInstallReports, shouldReload bool) error {
 	// get count of skipped reports
 	skipped := 0
 	for _, report := range reports {
@@ -552,6 +548,10 @@ func refreshConnectionsIfNecessary(ctx context.Context, reports display.PluginIn
 		steampipeconfig.GlobalConfig = config
 	}
 
+	// create a new context with spinner disabled so that
+	// updates from the underlying layers don't end up in the
+	// ui
+	ctx := statushooks.DisableStatusHooks(parentCtx)
 	client, err := db_local.GetLocalClient(ctx, constants.InvokerPlugin, nil)
 	if err != nil {
 		return err
@@ -667,9 +667,9 @@ func runPluginUninstallCmd(cmd *cobra.Command, args []string) {
 	}
 
 	reports := display.PluginRemoveReports{}
-	spinner := statushooks.NewStatusSpinner(statushooks.WithMessage(fmt.Sprintf("Uninstalling %s", utils.Pluralize("plugin", len(args)))))
+	statushooks.SetStatus(ctx, fmt.Sprintf("Uninstalling %s", utils.Pluralize("plugin", len(args))))
 	for _, p := range args {
-		spinner.SetStatus(fmt.Sprintf("Uninstalling %s", p))
+		statushooks.SetStatus(ctx, fmt.Sprintf("Uninstalling %s", p))
 		if report, err := plugin.Remove(ctx, p, connectionMap); err != nil {
 			if strings.Contains(err.Error(), "not found") {
 				exitCode = constants.ExitCodePluginNotFound
@@ -680,23 +680,26 @@ func runPluginUninstallCmd(cmd *cobra.Command, args []string) {
 			reports = append(reports, *report)
 		}
 	}
-	spinner.Done()
+	statushooks.Done(ctx)
 	reports.Print()
 }
 
 func getPluginConnectionMap(ctx context.Context) (map[string][]modconfig.Connection, *steampipeconfig.RefreshConnectionResult, error) {
+	statushooks.SetStatus(ctx, "Fetching connection map")
+	defer statushooks.Done(ctx)
 	client, err := db_local.GetLocalClient(ctx, constants.InvokerPlugin, nil)
 	if err != nil {
 		return nil, nil, err
 	}
 	defer client.Close(ctx)
-	res := client.RefreshConnectionAndSearchPaths(ctx)
+
+	res := client.RefreshConnectionAndSearchPaths(statushooks.DisableStatusHooks(ctx))
 	if res.Error != nil {
 		return nil, nil, res.Error
 	}
 
 	pluginConnectionMap := make(map[string][]modconfig.Connection)
-	for _, v := range *client.ConnectionMap() {
+	for _, v := range res.ConnectionMap {
 		_, found := pluginConnectionMap[v.Plugin]
 		if !found {
 			pluginConnectionMap[v.Plugin] = []modconfig.Connection{}
