@@ -121,7 +121,7 @@ func runQueryCmd(cmd *cobra.Command, args []string) {
 		return
 	}
 
-	// enable spinner only in interactive mode
+	// enable paging only in interactive mode
 	interactiveMode := len(args) == 0
 	// set config to indicate whether we are running an interactive query
 	viper.Set(constants.ConfigKeyInteractive, interactiveMode)
@@ -135,26 +135,28 @@ func runQueryCmd(cmd *cobra.Command, args []string) {
 	}
 	defer initData.Cleanup(ctx)
 
+	var failures int
 	switch {
 	case interactiveMode:
-		queryexecute.RunInteractiveSession(ctx, initData)
+		err = queryexecute.RunInteractiveSession(ctx, initData)
 	case snapshotRequired():
 		// if we are either outputting snapshot format, or sharing the results as a snapshot, execute the query
 		// as a dashboard
-		failures := executeSnapshotQuery(initData, ctx)
-		if failures != 0 {
-			exitCode = constants.ExitCodeQueryExecutionFailed
-		}
+		failures = executeSnapshotQuery(initData, ctx)
 	default:
 		// NOTE: disable any status updates - we do not want 'loading' output from any queries
 		ctx = statushooks.DisableStatusHooks(ctx)
 
 		// fall through to running a batch query
-		// set global exit code
-		failures := queryexecute.RunBatchSession(ctx, initData)
-		if failures != 0 {
-			exitCode = constants.ExitCodeQueryExecutionFailed
-		}
+		failures, err = queryexecute.RunBatchSession(ctx, initData)
+	}
+
+	// check for err and set the exit code else set the exit code if some queries failed or some rows returned an error
+	if err != nil {
+		exitCode = constants.ExitCodeInitializationFailed
+		error_helpers.ShowError(ctx, err)
+	} else if failures > 0 {
+		exitCode = constants.ExitCodeQueryExecutionFailed
 	}
 }
 
@@ -193,6 +195,7 @@ func executeSnapshotQuery(initData *query.InitData, ctx context.Context) int {
 	// wait for init
 	<-initData.Loaded
 	if err := initData.Result.Error; err != nil {
+		exitCode = constants.ExitCodeInitializationFailed
 		error_helpers.FailOnError(err)
 	}
 
@@ -205,7 +208,7 @@ func executeSnapshotQuery(initData *query.InitData, ctx context.Context) int {
 			resolvedQuery := initData.Queries[name]
 			// if a manual query is being run (i.e. not a named query), convert into a query and add to workspace
 			// this is to allow us to use existing dashboard execution code
-			queryProvider, existingResource := ensureQueryResource(name, resolvedQuery, initData.Workspace)
+			queryProvider, existingResource := ensureSnapshotQueryResource(name, resolvedQuery, initData.Workspace)
 
 			// we need to pass the embedded initData to  GenerateSnapshot
 			baseInitData := &initData.InitData
@@ -249,21 +252,22 @@ func executeSnapshotQuery(initData *query.InitData, ctx context.Context) int {
 
 			// export the result if necessary
 			exportArgs := viper.GetStringSlice(constants.ArgExport)
-			err = initData.ExportManager.DoExport(ctx, snap.FileNameRoot, snap, exportArgs)
+			exportMsg, err := initData.ExportManager.DoExport(ctx, snap.FileNameRoot, snap, exportArgs)
 			error_helpers.FailOnErrorWithMessage(err, "failed to export snapshot")
+			// print the location where the file is exported
+			if len(exportMsg) > 0 && viper.GetBool(constants.ArgProgress) {
+				fmt.Printf("\n")
+				fmt.Println(strings.Join(exportMsg, "\n"))
+				fmt.Printf("\n")
+			}
 		}
 	}
 	return 0
 }
 
 func snapshotToQueryResult(snap *dashboardtypes.SteampipeSnapshot, name string) (*queryresult.Result, error) {
-	// find chart node - we expect only 1
-	parsedName, err := modconfig.ParseResourceName(name)
-	if err != nil {
-		return nil, err
-	}
-	tableName := modconfig.BuildFullResourceName(parsedName.Mod, modconfig.BlockTypeTable, parsedName.Name)
-	tablePanel, ok := snap.Panels[tableName]
+	// the table of a snapshot query has a fixed name
+	tablePanel, ok := snap.Panels[modconfig.SnapshotQueryTableName]
 	if !ok {
 		return nil, fmt.Errorf("dashboard does not contain table result for query")
 	}
@@ -280,8 +284,11 @@ func snapshotToQueryResult(snap *dashboardtypes.SteampipeSnapshot, name string)
 
 	// start a goroutine to stream the results as rows
 	go func() {
-		rowVals := make([]interface{}, len(chartRun.Data.Columns))
 		for _, d := range chartRun.Data.Rows {
+			// we need to allocate a new slice everytime, since this gets read
+			// asynchronously on the other end and we need to make sure that we don't overwrite
+			// data already sent
+			rowVals := make([]interface{}, len(chartRun.Data.Columns))
 			for i, c := range chartRun.Data.Columns {
 				rowVals[i] = d[c.Name]
 			}
@@ -296,7 +303,7 @@ func snapshotToQueryResult(snap *dashboardtypes.SteampipeSnapshot, name string)
 
 // convert the given command line query into a query resource and add to workspace
 // this is to allow us to use existing dashboard execution code
-func ensureQueryResource(name string, resolvedQuery *modconfig.ResolvedQuery, w *workspace.Workspace) (queryProvider modconfig.HclResource, existingResource bool) {
+func ensureSnapshotQueryResource(name string, resolvedQuery *modconfig.ResolvedQuery, w *workspace.Workspace) (queryProvider modconfig.HclResource, existingResource bool) {
 	// is this an existing resource?
 	if parsedName, err := modconfig.ParseResourceName(name); err == nil {
 		if resource, found := w.GetResource(parsedName); found {
@@ -308,7 +315,7 @@ func ensureQueryResource(name string, resolvedQuery *modconfig.ResolvedQuery, w
 	shortName := "command_line_query"
 
 	// this is NOT a named query - create the query using RawSql
-	q := modconfig.NewQuery(&hcl.Block{}, w.Mod, shortName).(*modconfig.Query)
+	q := modconfig.NewQuery(&hcl.Block{Type: modconfig.BlockTypeQuery}, w.Mod, shortName).(*modconfig.Query)
 	q.SQL = utils.ToStringPointer(resolvedQuery.RawSQL)
 	q.SetArgs(resolvedQuery.QueryArgs())
 	// add empty metadata
