@@ -3,7 +3,6 @@ package db_common
 import (
 	"context"
 	"database/sql"
-
 	"github.com/turbot/steampipe/pkg/query/queryresult"
 	"github.com/turbot/steampipe/pkg/schema"
 	"github.com/turbot/steampipe/pkg/steampipeconfig"
@@ -13,14 +12,14 @@ type Client interface {
 	Close(ctx context.Context) error
 
 	ForeignSchemaNames() []string
-	LoadForeignSchemaNames(ctx context.Context) error
-	ConnectionMap() *steampipeconfig.ConnectionDataMap
+	AllSchemaNames() []string
+	LoadSchemaNames(ctx context.Context) error
 
 	GetCurrentSearchPath(context.Context) ([]string, error)
 	GetCurrentSearchPathForDbConnection(context.Context, *sql.Conn) ([]string, error)
 	SetRequiredSessionSearchPath(context.Context) error
 	GetRequiredSessionSearchPath() []string
-	ContructSearchPath(context.Context, []string, []string) ([]string, error)
+	ConstructSearchPath(context.Context, []string, []string) ([]string, error)
 
 	AcquireSession(context.Context) *AcquireSessionResult
 
