@@ -3,7 +3,6 @@ package initialisation
 import (
 	"context"
 	"fmt"
-	"github.com/turbot/steampipe/pkg/error_helpers"
 
 	"github.com/jackc/pgx/v5"
 	"github.com/spf13/viper"
@@ -16,6 +15,7 @@ import (
 	"github.com/turbot/steampipe/pkg/export"
 	"github.com/turbot/steampipe/pkg/modinstaller"
 	"github.com/turbot/steampipe/pkg/statushooks"
+	"github.com/turbot/steampipe/pkg/steampipeconfig"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 	"github.com/turbot/steampipe/pkg/workspace"
 )
@@ -30,6 +30,7 @@ type InitData struct {
 
 	ShutdownTelemetry func()
 	ExportManager     *export.Manager
+	ConnectionMap     steampipeconfig.ConnectionDataMap
 }
 
 func NewErrorInitData(err error) *InitData {
@@ -38,9 +39,8 @@ func NewErrorInitData(err error) *InitData {
 	}
 }
 
-func NewInitData(w *workspace.Workspace) *InitData {
+func NewInitData() *InitData {
 	i := &InitData{
-		Workspace:     w,
 		Result:        &db_common.InitResult{},
 		ExportManager: export.NewManager(),
 	}
@@ -56,7 +56,7 @@ func (i *InitData) RegisterExporters(exporters ...export.Exporter) *InitData {
 	return i
 }
 
-func (i *InitData) Init(ctx context.Context, invoker constants.Invoker) (res *InitData) {
+func (i *InitData) Init(ctx context.Context, invoker constants.Invoker) {
 	defer func() {
 		if r := recover(); r != nil {
 			i.Result.Error = helpers.ToError(r)
@@ -66,8 +66,8 @@ func (i *InitData) Init(ctx context.Context, invoker constants.Invoker) (res *In
 			i.Result.Error = ctx.Err()
 		}
 	}()
-	// return ourselves
-	res = i
+
+	statushooks.SetStatus(ctx, "Initializing")
 
 	// initialise telemetry
 	shutdownTelemetry, err := telemetry.Init(constants.AppName)
@@ -79,6 +79,7 @@ func (i *InitData) Init(ctx context.Context, invoker constants.Invoker) (res *In
 
 	// install mod dependencies if needed
 	if viper.GetBool(constants.ArgModInstall) {
+		statushooks.SetStatus(ctx, "Installing workspace dependencies")
 		opts := &modinstaller.InstallOpts{WorkspacePath: viper.GetString(constants.ArgModLocation)}
 		_, err := modinstaller.InstallWorkspaceDependencies(opts)
 		if err != nil {
@@ -97,6 +98,7 @@ func (i *InitData) Init(ctx context.Context, invoker constants.Invoker) (res *In
 	// set cloud metadata (may be nil)
 	i.Workspace.CloudMetadata = cloudMetadata
 
+	statushooks.SetStatus(ctx, "Checking for required plugins")
 	// check if the required plugins are installed
 	err = i.Workspace.CheckRequiredPluginsInstalled()
 	if err != nil {
@@ -124,6 +126,7 @@ func (i *InitData) Init(ctx context.Context, invoker constants.Invoker) (res *In
 		i.Result.AddMessage(fmt.Sprintf(format, a...))
 	})
 
+	statushooks.SetStatus(ctx, "Connecting to steampipe")
 	client, err := GetDbClient(getClientCtx, invoker, ensureSessionData)
 	if err != nil {
 		i.Result.Error = err
@@ -132,31 +135,25 @@ func (i *InitData) Init(ctx context.Context, invoker constants.Invoker) (res *In
 	i.Client = client
 
 	// refresh connections
+	statushooks.SetStatus(ctx, "Refreshing connections")
 	refreshResult := i.Client.RefreshConnectionAndSearchPaths(ctx)
 	if refreshResult.Error != nil {
 		i.Result.Error = refreshResult.Error
 		return
 	}
+	i.ConnectionMap = refreshResult.ConnectionMap
 
-	// force creation of session data - se we see any prepared statement errors at once
-	sessionResult := i.Client.AcquireSession(ctx)
-	i.Result.AddWarnings(sessionResult.Warnings...)
-	if sessionResult.Error != nil {
-		i.Result.Error = fmt.Errorf("error acquiring database connection, %s", sessionResult.Error.Error())
-	} else {
-		sessionResult.Session.Close(error_helpers.IsContextCanceled(ctx))
-	}
 	// add refresh connection warnings
 	i.Result.AddWarnings(refreshResult.Warnings...)
-
-	return
 }
 
 // GetDbClient either creates a DB client using the configured connection string (if present) or creates a LocalDbClient
 func GetDbClient(ctx context.Context, invoker constants.Invoker, onConnectionCallback db_client.DbConnectionCallback) (client db_common.Client, err error) {
 	if connectionString := viper.GetString(constants.ArgConnectionString); connectionString != "" {
+		statushooks.SetStatus(ctx, "Connecting to remote Steampipe database")
 		client, err = db_client.NewDbClient(ctx, connectionString, onConnectionCallback)
 	} else {
+		statushooks.SetStatus(ctx, "Starting local Steampipe database")
 		client, err = db_local.GetLocalClient(ctx, invoker, onConnectionCallback)
 	}
 	return client, err
