@@ -58,12 +58,16 @@ func NewDashboard(block *hcl.Block, mod *Mod, shortName string) HclResource {
 
 // NewQueryDashboard creates a dashboard to wrap a query/control
 // this is used for snapshot generation
-func NewQueryDashboard(q ModTreeItem) (*Dashboard, error) {
-	parsedName, err := ParseResourceName(q.Name())
+func NewQueryDashboard(qp QueryProvider) (*Dashboard, error) {
+	parsedName, title, err := getQueryDashboardName(qp)
 	if err != nil {
 		return nil, err
 	}
-	dashboardName := BuildFullResourceName(q.GetMod().ShortName, BlockTypeDashboard, parsedName.Name)
+
+	// for query dashboard use generated title, for control use original title
+	if qp.BlockType() != BlockTypeQuery {
+		title = qp.GetTitle()
+	}
 
 	var dashboard = &Dashboard{
 		ResourceWithMetadataImpl: ResourceWithMetadataImpl{
@@ -72,29 +76,54 @@ func NewQueryDashboard(q ModTreeItem) (*Dashboard, error) {
 		ModTreeItemImpl: ModTreeItemImpl{
 			HclResourceImpl: HclResourceImpl{
 				ShortName:       parsedName.Name,
-				FullName:        dashboardName,
-				UnqualifiedName: fmt.Sprintf("%s.%s", BlockTypeDashboard, parsedName),
-				Title:           utils.ToStringPointer(q.GetTitle()),
-				Description:     utils.ToStringPointer(q.GetDescription()),
-				Documentation:   utils.ToStringPointer(q.GetDocumentation()),
-				Tags:            q.GetTags(),
+				FullName:        parsedName.ToFullName(),
+				UnqualifiedName: parsedName.ToResourceName(),
+				Title:           utils.ToStringPointer(title),
+				Description:     utils.ToStringPointer(qp.GetDescription()),
+				Documentation:   utils.ToStringPointer(qp.GetDocumentation()),
+				Tags:            qp.GetTags(),
 				blockType:       BlockTypeDashboard,
 			},
-			Mod: q.GetMod(),
+			Mod: qp.GetMod(),
 		},
 	}
 
 	dashboard.setUrlPath()
 
-	chart, err := NewQueryDashboardTable(q)
+	table, err := NewQueryDashboardTable(qp)
 	if err != nil {
 		return nil, err
 	}
-	dashboard.children = []ModTreeItem{chart}
+	dashboard.children = []ModTreeItem{table}
 
 	return dashboard, nil
 }
 
+func getQueryDashboardName(qp QueryProvider) (*ParsedResourceName, string, error) {
+	var sql string
+	if q := qp.GetQuery(); q != nil {
+		sql = typehelpers.SafeString(q.GetSQL())
+	} else {
+		sql = typehelpers.SafeString(qp.GetSQL())
+	}
+	hash, err := utils.Base36Hash(sql, 8)
+	if err != nil {
+		return nil, "", err
+	}
+	dashboardName := fmt.Sprintf("custom.dashboard.sql_%s", hash)
+
+	parsed, err := ParseResourceName(dashboardName)
+	if err != nil {
+		return nil, "", err
+	}
+	title := getQueryDashboardTitle(hash)
+	return parsed, title, nil
+}
+
+func getQueryDashboardTitle(queryHash string) string {
+	return fmt.Sprintf("Custom query [%s]", queryHash)
+}
+
 func (d *Dashboard) setUrlPath() {
 	d.UrlPath = fmt.Sprintf("/%s", d.FullName)
 }
