@@ -1,19 +1,13 @@
 import ErrorPanel from "../../Error";
 import has from "lodash/has";
 import merge from "lodash/merge";
+import Placeholder from "../../Placeholder";
 import React, { useEffect, useRef, useState } from "react";
 import ReactEChartsCore from "echarts-for-react/lib/core";
 import set from "lodash/set";
 import useChartThemeColors from "../../../../hooks/useChartThemeColors";
 import useMediaMode from "../../../../hooks/useMediaMode";
-import {
-  BarChart,
-  GraphChart,
-  LineChart,
-  PieChart,
-  SankeyChart,
-  TreeChart,
-} from "echarts/charts";
+import useTemplateRender from "../../../../hooks/useTemplateRender";
 import {
   buildChartDataset,
   getColorOverride,
@@ -21,14 +15,6 @@ import {
   themeColors,
   Width,
 } from "../../common";
-import { CanvasRenderer } from "echarts/renderers";
-import {
-  DatasetComponent,
-  GridComponent,
-  LegendComponent,
-  TitleComponent,
-  TooltipComponent,
-} from "echarts/components";
 import { EChartsOption } from "echarts-for-react/src/types";
 import {
   ChartProperties,
@@ -42,28 +28,9 @@ import { FlowType } from "../../flows/types";
 import { getChartComponent } from "..";
 import { GraphType } from "../../graphs/types";
 import { HierarchyType } from "../../hierarchies/types";
-import { LabelLayout } from "echarts/features";
 import { registerComponent } from "../../index";
-import { renderInterpolatedTemplates } from "../../../../utils/template";
 import { useDashboard } from "../../../../hooks/useDashboard";
 import { useNavigate } from "react-router-dom";
-import * as echarts from "echarts/core";
-
-echarts.use([
-  BarChart,
-  CanvasRenderer,
-  DatasetComponent,
-  GraphChart,
-  GridComponent,
-  LabelLayout,
-  LegendComponent,
-  LineChart,
-  PieChart,
-  SankeyChart,
-  TitleComponent,
-  TooltipComponent,
-  TreeChart,
-]);
 
 const getThemeColorsWithPointOverrides = (
   type: ChartType = "column",
@@ -662,12 +629,12 @@ const buildChartOptions = (props: ChartProps, themeColors: any) => {
   );
 };
 
-interface ChartComponentProps {
+type ChartComponentProps = {
   options: EChartsOption;
   type: ChartType | FlowType | GraphType | HierarchyType;
-}
+};
 
-const handleClick = async (params: any, navigate) => {
+const handleClick = async (params: any, navigate, renderTemplates) => {
   const componentType = params.componentType;
   if (componentType !== "series") {
     return;
@@ -679,7 +646,7 @@ const handleClick = async (params: any, navigate) => {
       if (!params.data.href) {
         return;
       }
-      const renderedResults = await renderInterpolatedTemplates(
+      const renderedResults = await renderTemplates(
         { graph_node: params.data.href as string },
         [params.data]
       );
@@ -689,10 +656,17 @@ const handleClick = async (params: any, navigate) => {
 };
 
 const Chart = ({ options, type }: ChartComponentProps) => {
+  const [echarts, setEcharts] = useState<any | null>(null);
   const navigate = useNavigate();
   const chartRef = useRef<ReactEChartsCore>(null);
   const [imageUrl, setImageUrl] = useState<string | null>(null);
   const mediaMode = useMediaMode();
+  const { ready: templateRenderReady, renderTemplates } = useTemplateRender();
+
+  // Dynamically import echarts from its own bundle
+  useEffect(() => {
+    import("./echarts").then((m) => setEcharts(m.echarts));
+  }, []);
 
   useEffect(() => {
     if (!chartRef.current || !options) {
@@ -712,33 +686,37 @@ const Chart = ({ options, type }: ChartComponentProps) => {
   }
 
   const eventsDict = {
-    click: (params) => handleClick(params, navigate),
+    click: (params) => handleClick(params, navigate, renderTemplates),
   };
 
+  const PlaceholderComponent = Placeholder.component;
+
   return (
-    <>
-      {mediaMode !== "print" && (
-        <div className="relative">
-          <ReactEChartsCore
-            ref={chartRef}
-            echarts={echarts}
-            className="chart-canvas"
-            onEvents={eventsDict}
-            option={options}
-            notMerge={true}
-            lazyUpdate={true}
-            style={
-              type === "pie" || type === "donut" ? { height: "250px" } : {}
-            }
-          />
-        </div>
-      )}
-      {mediaMode === "print" && imageUrl && (
-        <div>
-          <img alt="Chart" className="max-w-full max-h-full" src={imageUrl} />
-        </div>
-      )}
-    </>
+    <PlaceholderComponent ready={!!echarts && templateRenderReady}>
+      <>
+        {mediaMode !== "print" && (
+          <div className="relative">
+            <ReactEChartsCore
+              ref={chartRef}
+              echarts={echarts}
+              className="chart-canvas"
+              onEvents={eventsDict}
+              option={options}
+              notMerge={true}
+              lazyUpdate={true}
+              style={
+                type === "pie" || type === "donut" ? { height: "250px" } : {}
+              }
+            />
+          </div>
+        )}
+        {mediaMode === "print" && imageUrl && (
+          <div>
+            <img alt="Chart" className="max-w-full max-h-full" src={imageUrl} />
+          </div>
+        )}
+      </>
+    </PlaceholderComponent>
   );
 };
 
