@@ -1,17 +1,21 @@
 import { BasePrimitiveProps, ExecutablePrimitiveProps } from "../common";
-import React from "react";
+import { ComponentType } from "react";
+import { PanelDefinition } from "../../../types";
 
-export type BaseInputProps = BasePrimitiveProps & ExecutablePrimitiveProps;
+export type BaseInputProps = PanelDefinition &
+  BasePrimitiveProps &
+  ExecutablePrimitiveProps;
 
-interface SelectInputOption {
+export type SelectInputOption = {
   name: string;
   label?: string;
-}
+};
 
 export type InputProperties = {
   label?: string;
   options?: SelectInputOption[];
   placeholder?: string;
+  unqualified_name: string;
 };
 
 export type InputProps = BaseInputProps & {
@@ -28,7 +32,7 @@ export type InputType =
   | "table"
   | "text";
 
-export interface IInput {
+export type IInput = {
   type: InputType;
-  component: React.ComponentType<any>;
-}
+  component: ComponentType<any>;
+};
